@@ -1,5 +1,6 @@
 pub(crate) mod checker;
 pub(crate) mod cli;
-pub(crate) mod helpers;
+pub(crate) mod io;
 
 use checker::KakouneChecker;
+pub use io::{new_kakoune_io, StdKakouneIO};
