@@ -2,28 +2,28 @@
 extern crate diesel;
 #[macro_use]
 extern crate diesel_migrations;
-
 #[macro_use]
 extern crate lazy_static;
 
 pub(crate) mod checker;
 pub mod cli;
-pub(crate) mod db;
 mod dictionary;
 pub(crate) mod interactor;
 pub mod kak;
-pub(crate) mod models;
-pub(crate) mod repo;
-pub(crate) mod schema;
-pub(crate) mod token;
+pub(crate) mod os_io;
+pub(crate) mod project;
+pub(crate) mod repository;
+pub mod sql;
+pub(crate) mod tokens;
 
 use checker::{Checker, InteractiveChecker, NonInteractiveChecker};
-use db::Db;
 use dictionary::Dictionary;
-use dictionary::EnchantDictionary;
+pub use dictionary::EnchantDictionary;
 use interactor::{ConsoleInteractor, Interactor};
-use repo::Repo;
-use token::TokenProcessor;
+pub use os_io::StandardIO;
+use project::{Project, ProjectId, ProjectPath, RelativePath};
+use repository::Repository;
+use tokens::TokenProcessor;
 
 #[cfg(test)]
 mod tests;
