@@ -1,7 +1,9 @@
 mod fake_dictionary;
 mod fake_interactor;
+mod fake_io;
 mod fake_repository;
 
 pub(crate) use fake_dictionary::FakeDictionary;
 pub(crate) use fake_interactor::FakeInteractor;
-pub(crate) use fake_repository::FakeRepo;
+pub(crate) use fake_io::FakeIO;
+pub(crate) use fake_repository::FakeRepository;
